function asa = getAdditionalSubmitArguments(props)

% wiki: 

% Copyright 2010-2015 The MathWorks, Inc.

asa = '';

[~,flag] = strtok(props.MatlabArguments,'p');
if strcmp(flag,'parallel')
    w = props.NumberOfTasks;
else
    w = 1;
end

% Number of nodes/cores
ppn = ClusterInfo.getProcsPerNode();
if isempty(ppn)==false
    % Don't request more cores/node than workers
    ppn = min(w,ppn);
    asa = sprintf('%s -n %d --ntasks-per-node=%d',asa,w,ppn);
else
    % Let SLURM figure out the number of nodes
    asa = sprintf('%s -n %d',asa,w);
end


%% REQUIRED


%% OPTIONAL

% Project Name
pn = ClusterInfo.getProjectName();
if isempty(pn)==false
    asa = [asa ' -A ' pn];
end

% Walltime
wt = ClusterInfo.getWallTime();
if isempty(wt)==false
    asa = [asa ' -t ' wt];
end

% Account
acnt = ClusterInfo.getAccount();
if isempty(acnt)==false
    asa = [asa ' --account=' acnt];
end

% Quality of Service
qos = ClusterInfo.getQualityOfService();
if isempty(qos)==false
    asa = [asa ' --qos=' qos];
end

% Partition
% Check for GPU
gpu = ClusterInfo.getUseGpu();
if gpu==true
    ngpus = ClusterInfo.getGpusPerNode();
    if isempty(ngpus)
        ngpus = 1;
    end
    ngpus = num2str(ngpus);
    qn = ['hpg2-gpu --gres=gpu:tesla:' ngpus];
else
    qn = ClusterInfo.getQueueName();
end
if isempty(qn)==false
    asa = [asa ' --partition=' qn];
end

% Physical Memory used by a single core
mu = ClusterInfo.getMemUsage();
if isempty(mu)==false
    asa = [asa ' --mem-per-cpu=' mu];
end

% Run on exclusive node
ren = ClusterInfo.getRequireExclusiveNode();
if ren==true
    asa = [asa ' --exclusive'];
end

% Reservation
res = ClusterInfo.getReservation();
if isempty(res)==false
    asa = [asa ' --reservation=' res];
end

% Email notification
ea = ClusterInfo.getEmailAddress();
if isempty(ea)==false
    % User wants to be emailed the job status
    asa = [asa ' --mail-type=ALL --mail-user=' ea];
end

% Every job is going to require a certain number of MDCS licenses.
% Specification of MDCS licenses which must be allocated to this
% job.  The /etc/slurm/slurm.conf file must list
%
%   # MDCS licenses
%   Licenses=MATLAB_Distrib_Comp_Engine:32
%
% And then call
%
%   % scontrol reconfigure 
%
asa = sprintf('%s --licenses=MATLAB_Distrib_Comp_Engine:%d',asa,w);

% Catch-all
udo = ClusterInfo.getUserDefinedOptions();
if isempty(udo)==false
    asa = [asa ' ' udo];
end

asa = strtrim(asa);
